==> drumgizmo_0.9.14.orig.tar.gz: drumgizmo-0.9.14/test/drumkitcreatortest.cc <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/***************************************************************************
 *            drumkitcreatortest.cc
 *
 *  Sat Jan 14 15:55:39 CET 2017
 *  Copyright 2017 Andr Nusser
 *  andre.nusser@googlemail.com
 ****************************************************************************/

/*
 *  This file is part of DrumGizmo.
 *
 *  DrumGizmo is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  DrumGizmo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with DrumGizmo; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#include <cppunit/extensions/HelperMacros.h>

#include "drumkit_creator.h"

class DrumkitcreatorTest
	: public CppUnit::TestFixture
{
	CPPUNIT_TEST_SUITE(DrumkitcreatorTest);
	CPPUNIT_TEST(testTest);
	CPPUNIT_TEST_SUITE_END();

	DrumkitCreator drumkit_creator;

public:
	void setUp()
	{
	}

	void tearDown()
	{
	
	}

	//! This just creates some drumkit.
	void testTest()
	{
		drumkit_creator.createStdKit("stdkit");
	}
};

// Registers the fixture into the 'registry'
CPPUNIT_TEST_SUITE_REGISTRATION(DrumkitcreatorTest);

==> drumgizmo_0.9.18.1.orig.tar.gz: drumgizmo-0.9.18.1/test/drumkitcreatortest.cc <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/***************************************************************************
 *            drumkitcreatortest.cc
 *
 *  Sat Jan 14 15:55:39 CET 2017
 *  Copyright 2017 Andr Nusser
 *  andre.nusser@googlemail.com
 ****************************************************************************/

/*
 *  This file is part of DrumGizmo.
 *
 *  DrumGizmo is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  DrumGizmo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with DrumGizmo; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#include "dgunit.h"

#include "drumkit_creator.h"

class DrumkitcreatorTest
	: public DGUnit
{
public:
	DrumkitcreatorTest()
	{
		DGUNIT_TEST(DrumkitcreatorTest::testTest);
	}

	DrumkitCreator drumkit_creator;

	//! This just creates some drumkit.
	void testTest()
	{
		drumkit_creator.createStdKit("stdkit");
	}
};

// Registers the fixture into the 'registry'
static DrumkitcreatorTest test;
